/* 
 * SimCoupe : Copyright (c) Allan Skillman 1996.
 *
 * Header file resource.h : Initialisation of runtime resources
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef _RESOURCE_H
#define _RESOURCE_H

#define DEF_FONT "fixed"

typedef struct _cfg_block {
	int recalibrate;	/* attempt to keep the interrupt rate at 50/sec */
	char rom0[256];		/* SAM ROM 0 image filename */
	char rom1[256];		/* SAM ROM 1 image filename */
	char lib_dir[1024];	/* directory to check for support files */
	char disk_1[256];	/* floppy disk image in drive 1 */
	char disk_2[256];	/* floppy disk image in drive 2 */
	int ifreq;		/* how often interrupts arrive (counter-style only) */
	int rr;			/* refresh frequency */
	int flashing;		/* is flashing enabled? */
#ifdef SLOWDOWN
	int slowdown;		/* slowdown factor for very fast machines */
#endif
#ifdef JOY
	int use_js;		/* try to use a joystick */
	int js_tolerance;	/* joystick displacement tolerance */
	char js_device[256];	/* joystick device name (/dev/js[0|1]) */
#endif
	int externalMem;	/* No. Mb of external memory */

#ifndef VGA_DISPLAY
	char display[256];	/* X11 display name */
	char geometry[256];	/* X11 geometry spec. (size is ignored) */
	char font[256];		/* X11 font name */
	int use_mitshm;		/* attempt to use MIT-SHM for image transfer */
	int priv_cmap;		/* use a private colormap */
#endif
} cfg_block;

int get_resources(int *argcp, char **argvp);

extern cfg_block SimCoupeResources;

/* Macros for quick access to the resource block (defined in resource.c) */

#define GetCfg(field) SimCoupeResources.field
#define SetCfg(field,value) SimCoupeResources.field = value
#define SetCfgStr(field,value) strcpy(SimCoupeResources.field,value)

#endif

